# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Async.AsyncVisitor

Module implementing a node visitor to check async functions for use of synchronous functions.

### Global Attributes

None

### Classes

AsyncVisitor | Class implementing a node visitor for checking async functions for use of synchronous functions.

### Functions

None

## AsyncVisitor

Class implementing a node visitor for checking async functions for use of synchronous functions.

### Derived from

ast.NodeVisitor

### Class Attributes

HttpMethods
HttpPackages
OsPathFuncs
OsProcessMethods
OsWaitMethods
SubprocessMethods
Urllib3DangerousClasses

### Class Methods

None

### Methods

AsyncVisitor | Constructor
visit_AsyncFunctionDef | Public method to handle an async function definition.

### Static Methods

None

#### AsyncVisitor (Constructor)

AsyncVisitor(args, checker)

Constructor

args (dict)
  dictionary containing the checker arguments
checker (ImportsChecker)
  reference to the checker

#### AsyncVisitor.visit_AsyncFunctionDef

visit_AsyncFunctionDef(node)

Public method to handle an async function definition.

node (ast.AsyncFunctionDef)
  reference to the node to be processed

Up